CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
60 lines
1.5 KiB
Plaintext
60 lines
1.5 KiB
Plaintext
// RUN: %clang_cc1 -fsyntax-only -verify %s
|
|
|
|
#include "Inputs/cuda.h"
|
|
|
|
__global__ void g1(int x) {}
|
|
|
|
template <typename T> void t1(T arg) {
|
|
g1<<<arg, arg>>>(1);
|
|
}
|
|
|
|
void h1(int x) {}
|
|
int h2(int x) { return 1; }
|
|
|
|
int main(void) {
|
|
g1<<<1, 1>>>(42);
|
|
g1(42); // expected-error {{call to global function 'g1' not configured}}
|
|
g1<<<1>>>(42); // expected-error {{too few execution configuration arguments to kernel function call}}
|
|
g1<<<1, 1, 0, 0, 0>>>(42); // expected-error {{too many execution configuration arguments to kernel function call}}
|
|
|
|
t1(1);
|
|
|
|
h1<<<1, 1>>>(42); // expected-error {{kernel call to non-global function 'h1'}}
|
|
|
|
int (*fp)(int) = h2;
|
|
fp<<<1, 1>>>(42); // expected-error {{must have void return type}}
|
|
|
|
g1<<<undeclared, 1>>>(42); // expected-error {{use of undeclared identifier 'undeclared'}}
|
|
}
|
|
|
|
// Make sure we can call static member kernels.
|
|
template <typename > struct a0 {
|
|
template <typename T> static __global__ void Call(T);
|
|
};
|
|
struct a1 {
|
|
template <typename T> static __global__ void Call(T);
|
|
};
|
|
template <typename T> struct a2 {
|
|
static __global__ void Call(T);
|
|
};
|
|
struct a3 {
|
|
static __global__ void Call(int);
|
|
static __global__ void Call(void*);
|
|
};
|
|
|
|
struct b {
|
|
template <typename c> void d0(c arg) {
|
|
a0<c>::Call<<<0, 0>>>(arg);
|
|
a1::Call<<<0,0>>>(arg);
|
|
a2<c>::Call<<<0,0>>>(arg);
|
|
a3::Call<<<0, 0>>>(arg);
|
|
}
|
|
void d1(void* arg) {
|
|
a0<void*>::Call<<<0, 0>>>(arg);
|
|
a1::Call<<<0,0>>>(arg);
|
|
a2<void*>::Call<<<0,0>>>(arg);
|
|
a3::Call<<<0, 0>>>(arg);
|
|
}
|
|
void e() { d0(1); }
|
|
};
|